@@ -1,7 +1,7 @@
 package Bencher::Scenario::SortBySpec;
 
-our $DATE = '2016-01-05'; # DATE
-our $VERSION = '0.02'; # VERSION
+our $DATE = '2016-06-26'; # DATE
+our $VERSION = '0.03'; # VERSION
 
 use 5.010001;
 use strict;
@@ -78,11 +78,11 @@ __END__
 
 =head1 NAME
 
-Bencher::Scenario::SortBySpec
+Bencher::Scenario::SortBySpec - Benchmark Sort::BySpec (e.g. against Sort::ByExample, etc)
 
 =head1 VERSION
 
-This document describes version 0.02 of Bencher::Scenario::SortBySpec (from Perl distribution Bencher-Scenario-SortBySpec), released on 2016-01-05.
+This document describes version 0.03 of Bencher::Scenario::SortBySpec (from Perl distribution Bencher-Scenario-SortBySpec), released on 2016-06-26.
 
 =head1 SYNOPSIS
 
@@ -98,6 +98,8 @@ For more options (dump scenario, list/include/exclude/add participants, list/inc
 
 =head1 BENCHMARKED MODULES
 
+Version numbers shown below are the versions used when running the sample benchmark.
+
 L<Sort::ByExample> 0.007
 
 L<Sort::BySpec> 0.02
@@ -106,7 +108,7 @@ L<Sort::BySpec> 0.02
 
 =over
 
-=item * gen_sorter-sbe (perl_code)
+=item * gen_sorter-sbe (perl_code) [gen_sorter, sbe]
 
 Code template:
 
@@ -114,7 +116,7 @@ Code template:
 
 
 
-=item * gen_sorter-sbs (perl_code)
+=item * gen_sorter-sbs (perl_code) [gen_sorter, sbs]
 
 Code template:
 
@@ -122,7 +124,7 @@ Code template:
 
 
 
-=item * sort-sbe (perl_code)
+=item * sort-sbe (perl_code) [sort, sbe]
 
 Code template:
 
@@ -130,7 +132,7 @@ Code template:
 
 
 
-=item * sort-sbs (perl_code)
+=item * sort-sbs (perl_code) [sort, sbs]
 
 Code template:
 
@@ -138,41 +140,53 @@ Code template:
 
 
 
+=back
+
+=head1 BENCHMARK DATASETS
+
+=over
+
+=item * eg-num5-list10
+
+=item * eg-num5-list100
+
+=item * eg-num5-list1000
+
 =back
 
 =head1 SAMPLE BENCHMARK RESULTS
 
-Run on: perl: I<< v5.22.0 >>, CPU: I<< Intel(R) Core(TM) i5-2400 CPU @ 3.10GHz (4 cores) >>, OS: I<< GNU/Linux Debian version 8.0 >>, OS kernel: I<< Linux version 3.16.0-4-amd64 >>.
+Run on: perl: I<< v5.22.2 >>, CPU: I<< Intel(R) Core(TM) i7-4770 CPU @ 3.40GHz (4 cores) >>, OS: I<< GNU/Linux Debian version 8.0 >>, OS kernel: I<< Linux version 3.16.0-4-amd64 >>.
 
-Benchmark with default option:
+Benchmark with default options (C<< bencher -m SortBySpec >>):
 
- +-----+-------------------------------------------------------------+------------+-------------+---------+---------+
- | seq | name                                                        | rate       | time        | errors  | samples |
- +-----+-------------------------------------------------------------+------------+-------------+---------+---------+
- | 11  | {dataset=>"eg-num5-list1000",participant=>"sort-sbs"}       | 163        | 6.14ms      | 4.2e-06 | 20      |
- | 10  | {dataset=>"eg-num5-list100",participant=>"sort-sbs"}        | 1.68e+03   | 0.596ms     | 2.7e-07 | 20      |
- | 8   | {dataset=>"eg-num5-list1000",participant=>"sort-sbe"}       | 2062.038   | 0.4849571ms | 9.1e-11 | 20      |
- | 7   | {dataset=>"eg-num5-list100",participant=>"sort-sbe"}        | 19396.2    | 0.0515566ms | 9.2e-11 | 32      |
- | 9   | {dataset=>"eg-num5-list10",participant=>"sort-sbs"}         | 2.25e+04   | 0.0445ms    | 4e-08   | 20      |
- | 6   | {dataset=>"eg-num5-list10",participant=>"sort-sbe"}         | 9.5e+04    | 0.0105ms    | 1.3e-08 | 20      |
- | 0   | {dataset=>"eg-num5-list10",participant=>"gen_sorter-sbe"}   | 1.41e+05   | 0.00711ms   | 1.7e-08 | 20      |
- | 2   | {dataset=>"eg-num5-list1000",participant=>"gen_sorter-sbe"} | 1.4092e+05 | 0.0070962ms | 9.2e-11 | 20      |
- | 1   | {dataset=>"eg-num5-list100",participant=>"gen_sorter-sbe"}  | 1.42e+05   | 0.00706ms   | 3.3e-09 | 20      |
- | 5   | {dataset=>"eg-num5-list1000",participant=>"gen_sorter-sbs"} | 2.17e+05   | 0.00461ms   | 1.6e-09 | 21      |
- | 4   | {dataset=>"eg-num5-list100",participant=>"gen_sorter-sbs"}  | 2.18e+05   | 0.00459ms   | 5.7e-09 | 27      |
- | 3   | {dataset=>"eg-num5-list10",participant=>"gen_sorter-sbs"}   | 2.18e+05   | 0.00459ms   | 6.7e-09 | 20      |
- +-----+-------------------------------------------------------------+------------+-------------+---------+---------+
+ +----------------+------------------+-----------+------------+------------+---------+---------+
+ | participant    | dataset          | rate (/s) |  time (ms) | vs_slowest |  errors | samples |
+ +----------------+------------------+-----------+------------+------------+---------+---------+
+ | sort-sbs       | eg-num5-list1000 |     302   | 3.32       |      1     | 4.8e-07 |      20 |
+ | sort-sbe       | eg-num5-list1000 |    2900   | 0.344      |      9.63  | 5.3e-08 |      20 |
+ | sort-sbs       | eg-num5-list100  |    3110   | 0.322      |     10.3   | 1.6e-07 |      21 |
+ | sort-sbe       | eg-num5-list100  |   27600   | 0.0363     |     91.4   | 9.7e-09 |      38 |
+ | sort-sbs       | eg-num5-list10   |   41930.8 | 0.0238488  |    139.048 |   0     |      21 |
+ | sort-sbe       | eg-num5-list10   |  140000   | 0.0074     |    450     | 1.3e-08 |      20 |
+ | gen_sorter-sbe | eg-num5-list1000 |  249859   | 0.00400225 |    828.567 |   0     |      22 |
+ | gen_sorter-sbe | eg-num5-list100  |  249900   | 0.004002   |    828.7   | 8.7e-11 |      21 |
+ | gen_sorter-sbe | eg-num5-list10   |  250000   | 0.004      |    830     | 5.5e-09 |      29 |
+ | gen_sorter-sbs | eg-num5-list100  |  252185   | 0.00396534 |    836.28  |   0     |      20 |
+ | gen_sorter-sbs | eg-num5-list1000 |  253000   | 0.00396    |    837     | 1.3e-09 |      32 |
+ | gen_sorter-sbs | eg-num5-list10   |  250000   | 0.004      |    840     | 5.7e-09 |      27 |
+ +----------------+------------------+-----------+------------+------------+---------+---------+
 
 
-Benchmark module startup overhead:
+Benchmark module startup overhead (C<< bencher -m SortBySpec --module-startup >>):
 
- +-----+---------------------+--------+-------------------+---------+---------+
- | seq | name                | time   | mod_overhead_time | errors  | samples |
- +-----+---------------------+--------+-------------------+---------+---------+
- | 1   | Sort::ByExample     | 20ms   | 16ms              | 9e-05   | 20      |
- | 2   | Sort::BySpec        | 8.06ms | 3.53ms            | 1.7e-05 | 20      |
- | 0   | perl -e1 (baseline) | 4.5ms  | 0ms               | 2.7e-05 | 20      |
- +-----+---------------------+--------+-------------------+---------+---------+
+ +---------------------+-----------+------------------------+------------+---------+---------+
+ | participant         | time (ms) | mod_overhead_time (ms) | vs_slowest |  errors | samples |
+ +---------------------+-----------+------------------------+------------+---------+---------+
+ | Sort::ByExample     |      14   |                   11.5 |        1   | 5.3e-05 |      22 |
+ | Sort::BySpec        |       5   |                    2.5 |        2.7 | 2.8e-05 |      20 |
+ | perl -e1 (baseline) |       2.5 |                    0   |        5.5 | 4.5e-06 |      20 |
+ +---------------------+-----------+------------------------+------------+---------+---------+
 
 =head1 DESCRIPTION
 
